| as.promise.ncurlAio | R Documentation |
Creates a 'promise' from an 'ncurlAio' object.
## S3 method for class 'ncurlAio'
as.promise(x)
x |
an object of class 'ncurlAio'. |
This function is an S3 method for the generic as.promise for class
'ncurlAio'.
Requires the promises package.
Allows an 'ncurlAio' to be used with functions such as promises::then(),
which schedules a function to run upon resolution of the Aio.
The promise is resolved with a list of 'status', 'headers' and 'data' or rejected with the error translation if an NNG error is returned e.g. for an invalid address.
A 'promise' object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.