race_aio: Race Aio

View source: R/aio.R

race_aioR Documentation

Race Aio

Description

Returns the index of the first resolved Aio in a list, waiting if necessary.

Usage

race_aio(x, cv)

Arguments

x

A list of Aio objects.

cv

A condition variable. This must be the same cv supplied to recv_aio() or request() when creating the Aio objects in x.

Value

Integer index of the first resolved Aio, or 0L if none are resolved, the list is empty, or the cv was terminated.


nanonext documentation built on March 8, 2026, 9:06 a.m.