read_stdin: Read stdin

View source: R/utils.R

read_stdinR Documentation

Read stdin

Description

Reads stdin from a background thread, allowing the stream to be accessed as messages from an NNG 'inproc' socket. As the read is blocking, it can only be used in non-interactive sessions. Closing stdin causes the background thread to exit and the socket connection to end.

Usage

read_stdin()

Details

A 'pull' protocol socket is returned, and hence can only be used with receive functions.

Value

a Socket.


nanonext documentation built on March 8, 2026, 9:06 a.m.