Runs the later event loop, blocking until the next event and
dispatching any scheduled callbacks. Used to process a server's (see
http_server()) or other asynchronous operations' callbacks on R's main
thread.
Runs the later event loop, blocking until the next event and
dispatching any scheduled callbacks. Used to process a server's (see
http_server()) or other asynchronous operations' callbacks on R's main
thread.