| stop_request | R Documentation |
Stop an asynchronous Aio operation, or a list of Aio operations, created by
request(). This is an augmented version of stop_aio() that additionally
requests cancellation by sending an integer zero followed by the context ID
over the context, and waiting for the response.
stop_request(x)
x |
an Aio or list of Aios (objects of class 'recvAio' returned by
|
Invisibly, a logical vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.