| race_aio | R Documentation |
Returns the index of the first resolved Aio in a list, waiting if necessary.
race_aio(x, cv)
x |
A list of Aio objects. |
cv |
A condition variable. This must be the same cv supplied to
|
Integer index of the first resolved Aio, or 0L if none are resolved, the list is empty, or the cv was terminated.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.