powered by
Returns the index of the first resolved Aio in a list, waiting if necessary.
race_aio(x, cv)
Integer index of the first resolved Aio, or 0L if none are resolved, the list is empty, or the cv was terminated.
A list of Aio objects.
A condition variable. This must be the same cv supplied to recv_aio() or request() when creating the Aio objects in x.
recv_aio()
request()
x