Stop an asynchronous Aio operation, or a list of Aio operations, created by
request(). This is an augmented version of stop_aio() that additionally
requests cancellation by sending an integer zero followed by the context ID
over the context, and waiting for the response.
Arguments
- x
an Aio or list of Aios (objects of class 'recvAio' returned by
request()).